@@ -54,7 +54,7 @@ setMethod(".gedit",
             if (!is.null(container)) {
               if(is.logical(container) && container == TRUE)
                 container = gwindow()
-              add(container, obj)
+              add(container, obj,...)
             }
 
             if (!is.null(handler)) {
