@@ -271,21 +271,24 @@ addWidgetAtPoint = function(obj, value) {
   evb$ShowAll()
 
   ## connect move handler?
-  connectSignal(evb,
+  try(connectSignal(evb,
                 signal = "button-press-event",
                 f = movableWidgetButtonPressHandler,
                 data = list(obj=obj@widget),
-                user.data.first = TRUE)
-  connectSignal(evb,
+                user.data.first = TRUE),
+      silent=TRUE)
+  try(connectSignal(evb,
                 signal = "button-release-event",
                 f = movableWidgetButtonReleaseHandler,
                 data = list(obj=obj@widget),
-                user.data.first = TRUE)
-  connectSignal(evb,
+                user.data.first = TRUE),
+      silent=TRUE)
+  try(connectSignal(evb,
                 signal = "motion-notify-event",
                 f = movableWidgetButtonMotionNotifyHandler,
                 data = list(obj=obj@widget),
-                user.data.first = TRUE)
+                user.data.first = TRUE),
+      silent=TRUE)
   
   
   ## get xpos, ypos
